<div align="center">

# EBT Flash Attention

<img src="assets/energy_landscape.png" width="480">

</div>
Triton implemention of the Energy Based Transformer attention mechanism

## Description

Leverage Flash Attention Triton kernel i